﻿Copyright (c) (2016) Fluke Corporation                      MET/CAL Procedure
=============================================================================
INSTRUMENT:            Tek TDS 220: (1 Year) VER RS-232 /5500A+SC600
DATE:                  2017-01-30 08:31:43
AUTHOR:                Fluke Corporation
REVISION:              $Revision: 17927 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       3
NUMBER OF LINES:       209
CONFIGURATION:         Fluke 5500A (S6)
=============================================================================
#
# Source:
#   Tektronix TDS 210 & 220 Service Manual 070-9693-04
#
# Overview:
#   This procedure is written to verify the operation of the TDS 2xx
#   Oscilloscopes. This procedure performs a "closed-loop" verification
#   with a minimum of operater intervention.  The following documentation
#   lists the global registers used and subprocedures called.
#
# NUMERIC REGISTERS USED:
#
#   M[10]
#     This register is used to set watchdog timer in the event the
#     oscillscope does not respond to a status command.  THIS REGISTER IS
#     SOMETIMES USED IN THE MAIN PROCEDURE as a Watchdog timer also.
#
#   M[11]
#     This register is used to store the value of MEM
#
#   M[12]
#     This register is used to store the value of MEM1
#
#   M[17]
#     This register is used to store the desired resolution of a measurement.
#
#   M[1]
#     This register is used in the Trigger Section of the procedure to store
#     temporary values of MEM.  This section is part of a feedback loop which
#     is used to adjust the 5500 to the proper amplitude.
#
#   M[2]
#     This register is used in the Trigger Section of the procedure to
#     calculate how much the 5500 will be adjusted in the feedback loop.
#
#   M[3]
#     This register is used in the main triggering section to help determine
#     whether the scope is making a correct type of measurement.
#
#   M[4]
#     This register is used to store a value from the -0.600V DC Tests to be
#     to be compared later
#
#   M[5]
#     This register is used to store a value from the -0.900V DC Tests to be
#     to be compared later
#
#   M[7]
#     This wariable is used to determine whether the scope has triggered
#     properly and is used with the JMPL FSC.
#
#   M[8]
#     This register is used during the TIMEBASE test to store vertical
#     cursor information.
#
#   M[9]
#     This register is used during the TIMEBASE test to store horizontal
#     cursor information.
#
#   M[100]
#     Channel number
#
#   M[102]
#     Bandwidth in Megahertz (50, 100, 200, or 400)
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON
  1.001  ASK-   R   Q N              P                            F        W
# These statements are here to force the main procedure header to list the
# configuration required by the subprocedures.
  1.002  JMP          1.004
  1.003  5500         1V                                             S6 S

# Set timeout for OPC to 30s.
  1.004  MATH         M[88] = 30000

  1.005  RSLT         =
  1.006  HEAD         PRELIMINARY INSTRUCTIONS
  1.007  MATH         MEM2 = INI("startup", "port")
  1.008  JMPL         UUT_SERIAL_PORT ZCMPI(MEM2, "COM5500")

  1.009  DISP         Connect the UUT to [MEM2] using a DB9 female to DB9
  1.009  DISP         female null modem cable, Fluke PM 8914/001 CombiScope
  1.009  DISP         Serial Interface Cable or equivalent.
  1.010  JMPL         CONTINUE

  1.011  LABEL        UUT_SERIAL_PORT
  1.012  DISP         Connect UUT to the port labeled "SERIAL 2 TO UUT" on
  1.012  DISP         rear panel of 5500A using the DB9 male to DB9 female
  1.012  DISP         straight through cable, Fluke Part #943738 or
  1.012  DISP         equivalent.

  1.013  LABEL        CONTINUE
  1.014  DISP         Turn the UUT on.

  1.015  LABEL        SELF_TEST
  1.016  EVAL   -s "Self-Test" : Did the power-on self-test pass?

  2.001  DISP         Press UTILITY->Options->RS-232.
  2.001  DISP         Press "Set to default".

  2.002  PORT         [P9600,N,8,1,H][T10000]

  2.003  PORT         *RST;DESE 61[10]
  2.004  CALL         Sub Wait for Operation Complete (OPC) RS-232
  2.005  JMPL         ERROR          M[89] <= 0

# Put UUT identification string into results; allow for firmware documentation
  2.006  RSLT         =
  2.007  CALL         Sub IEEE-488.2 Identification Query (*IDN?) RS-232

  2.008  IF           NOT(FIND(S[2], "TDS 220", 1))
  2.009  DISP         A Tektronix TDS 220 Scope is not connected to [V Port].
  2.010  END
  2.011  ENDIF

  2.012  MATH         M[102] = 100

  2.013  DISP         Allow a 10 minute warm-up period before advancing...
  2.014  OPBR         -z It is recommended that a Signal Path Compensation
  2.014  OPBR         Test be performed before running the performance Test.
  2.014  OPBR         It is only necessary to run this test one time.
  2.014  OPBR         Do you want to run the Signal Path Compensation Test?

  2.015  IF           MEM1
  2.016  RSLT         =
  2.017  HEAD         SIGNAL PATH COMPENSATION
  2.018  DISP         Press UTILITY and select Do Self Cal to start the
  2.018  DISP         routine.  Follow the instructions on the UUT screen.
  2.018  DISP         The routine takes approximately one minute to complete.
  2.019  EVAL   -s "Signal Path Compensation Test" : Did Self Cal pass?
  3.001  ENDIF

  3.002  MATH         M[100] = 1
  3.003  PIC          55_2xx_1
  3.004  CALL         Sub Tek TDSxxx Channel Selection
  3.005  JMPL         ERROR          M[89] <= 0
  3.006  CALL         Sub TDS2xx (1 yr) DCV RS-232 /5500+S6
  3.007  JMPL         ERROR          M[89] <= 0
  3.008  JMPL         CH1_ANALOG_BANDWIDTH

  3.009  LABEL        CH2_DC_VOLTAGE
  3.010  MATH         M[100] = 2
  3.011  PIC          55_2xx_2
  3.012  CALL         Sub Tek TDSxxx Channel Selection
  3.013  JMPL         ERROR          M[89] <= 0
  3.014  CALL         Sub TDS2xx (1 yr) DCV RS-232 /5500+S6
  3.015  JMPL         ERROR          M[89] <= 0
  3.016  JMPL         CH2_ANALOG_BANDWIDTH

  3.017  LABEL        CH1_ANALOG_BANDWIDTH
  3.018  PIC          55_2xx1t
  3.019  CALL         Sub Tek TDSxxx Channel Selection
  3.020  JMPL         ERROR          M[89] <= 0
  3.021  CALL         Sub TDS2xx (1 yr) Bandwidth RS-232 /5500+S6
  3.022  JMPL         ERROR          M[89] <= 0
  3.023  JMPL         TIMEBASE_CHECK

  3.024  LABEL        CH2_ANALOG_BANDWIDTH
  3.025  PIC          55_2xx2t
  3.026  CALL         Sub Tek TDSxxx Channel Selection
  3.027  JMPL         ERROR          M[89] <= 0
  3.028  CALL         Sub TDS2xx (1 yr) Bandwidth RS-232 /5500+S6
  3.029  JMPL         ERROR          M[89] <= 0
  3.030  JMPL         CH2_TRIGGER

  3.031  LABEL        TIMEBASE_CHECK
  3.032  MATH         M[100] = 1
  3.033  CALL         Sub Tek TDSxxx Channel Selection
  3.034  JMPL         ERROR          M[89] <= 0
  3.035  CALL         Sub TDS2xx (1 yr) Timebase RS-232 /5500+S6
  3.036  JMPL         ERROR          M[89] <= 0
  3.037  MATH         M[100] = 1
  3.038  CALL         Sub Tek TDSxxx Channel Selection
  3.039  JMPL         ERROR          M[89] <= 0
  3.040  CALL         Sub TDS2xx (1 yr) Trigger RS-232 /5500+S6
  3.041  JMPL         ERROR          M[89] <= 0
  3.042  JMPL         CH2_DC_VOLTAGE

  3.043  LABEL        CH2_TRIGGER
  3.044  CALL         Sub Tek TDSxxx Channel Selection
  3.045  JMPL         ERROR          M[89] <= 0
  3.046  CALL         Sub TDS2xx (1 yr) Trigger RS-232 /5500+S6
  3.047  JMPL         ERROR          M[89] <= 0

  3.048  MATH         M[100] = 1
  3.049  PIC          55_2xx_e
  3.050  CALL         Sub Tek TDSxxx Channel Selection
  3.051  JMPL         ERROR          M[89] <= 0
  3.052  CALL         Sub TDS2xx (1 yr) Ext Trig RS-232 /5500+S6
  3.053  JMPL         ERROR          M[89] <= 0
  3.054  JMPL         END

  3.055  LABEL        ERROR
  3.056  HEAD         ERROR
  3.057  DISP         [SREG28]

  3.058  LABEL        END
  3.059  END
